@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
 from copy import copy
+from collections import Iterator
 
 from .games import CollectionBoardGame
 from .utils import DictObject
@@ -11,7 +12,7 @@ class Collection(DictObject):
         kw = copy(data)
         if "items" not in kw:
             kw["items"] = []
-        self.game_ids = set()
+        self.__game_ids = set()
         super(Collection, self).__init__(kw)
 
     def _format(self, log):
@@ -24,14 +25,14 @@ class Collection(DictObject):
             i._format(log)
             log.info("---------------------")
 
-    def add_game(self, game):
+    def _add_game(self, game):
         # Collections can have duplicate elements (different collection ids), so don't add the same thing multiple times
-        if game["id"] not in self.game_ids:
+        if game["id"] not in self.__game_ids:
             self._data["items"].append(game)
-            self.game_ids.add(game["id"])
+            self.__game_ids.add(game["id"])
 
-    def __unicode__(self):
-        return "{}'s collection, {} items".format(self.username, len(self.games))
+    def __str__(self):
+        return "{}'s collection, {} items".format(self.owner, len(self))
 
     def __len__(self):
         return len(self._data["items"])
@@ -40,14 +41,10 @@ class Collection(DictObject):
     def owner(self):
         return self._data.get("owner")
 
-    @property
-    def size(self):
-        return len(self._data["items"])
-
     @property
     def items(self):
         return [CollectionBoardGame(x) for x in self._data["items"]]
 
-    def iteritems(self):
+    def __iter__(self):
         for item in self._data["items"]:
             yield CollectionBoardGame(item)
